#ifndef NT2_INCLUDE_FUNCTIONS_ISTRIANGULAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISTRIANGULAR_HPP_INCLUDED

#include <nt2/predicates/include/functions/istriangular.hpp>

#endif
